#!/bin/sh
set -e

mkdir tests/data/fexist/dir
touch tests/data/fexist/regular
touch tests/data/fexist/executable
chmod +x tests/data/fexist/executable
touch tests/data/which/regular
touch tests/data/which/executable
chmod +x tests/data/which/executable
autoreconf -if
./configure
make check
make clean
